@@ -1,64 +1,88 @@
 import matplotlib.pyplot as plt
+import matplotlib.axes
 from matplotlib.ticker import MaxNLocator
 import numpy as np
 import numbers
-from .reference_points import create_references
+
+from typing import Iterable, List, Optional, Sequence, Tuple, Union
+
+from ..result import Result
+from .reference_points import create_references, ReferencePoint
 from .clust_color import assign_colors
 from .clust_color import delete_nan_inf
 from .misc import process_result_list
 
 
-def parameters(results, ax=None, free_indices_only=True, lb=None, ub=None,
-               size=None, reference=None, colors=None, legends=None,
-               balance_alpha=True, start_indices=None):
+def parameters(
+        results: Union[Result, Sequence[Result]],
+        ax: Optional[matplotlib.axes.Axes] = None,
+        parameter_indices: Union[str, Sequence[int]] = 'free_only',
+        lb: Optional[Union[np.ndarray, List[float]]] = None,
+        ub: Optional[Union[np.ndarray, List[float]]] = None,
+        size: Optional[Tuple[float, float]] = None,
+        reference: Optional[List[ReferencePoint]] = None,
+        colors: Optional[Union[List[float], List[List[float]]]] = None,
+        legends: Optional[Union[str, List[str]]] = None,
+        balance_alpha: bool = True,
+        start_indices: Optional[Union[int, Iterable[int]]] = None
+) -> matplotlib.axes.Axes:
     """
     Plot parameter values.
 
     Parameters
     ----------
-    results: pypesto.Result or list
+    results:
         Optimization result obtained by 'optimize.py' or list of those
-    ax: matplotlib.Axes, optional
+    ax:
         Axes object to use.
-    free_indices_only: bool, optional
-        If True, only free parameters are shown. If
-        False, also the fixed parameters are shown.
-    lb, ub: ndarray, optional
+    parameter_indices:
+        Specifies which parameters should be plotted. Allowed string values are
+        'all' (both fixed and free parameters will be plotted)  and
+        'free_only' (only free parameters will be plotted)
+    lb, ub:
         If not None, override result.problem.lb, problem.problem.ub.
         Dimension either result.problem.dim or result.problem.dim_full.
-    size: tuple, optional
+    size:
         Figure size (width, height) in inches. Is only applied when no ax
         object is specified
-    reference: list, optional
-        List of reference points for optimization results, containing et
+    reference:
+        List of reference points for optimization results, containing at
         least a function value fval
-    colors: list, or RGBA, optional
-        list of colors, or single color
-        color or list of colors for plotting. If not set, clustering is done
-        and colors are assigned automatically
-    legends: list or str
+    colors:
+        list of RGBA colors, or single RGBA color
+        If not set, clustering is done and colors are assigned automatically
+    legends:
         Labels for line plots, one label per result object
-    balance_alpha: bool (optional)
+    balance_alpha:
         Flag indicating whether alpha for large clusters should be reduced to
         avoid overplotting (default: True)
-    start_indices: list or int
+    start_indices:
         list of integers specifying the multistarts to be plotted or
         int specifying up to which start index should be plotted
 
     Returns
     -------
-    ax: matplotlib.Axes
+    ax:
         The plot axes.
     """
 
     # parse input
     (results, colors, legends) = process_result_list(results, colors, legends)
 
+    if isinstance(parameter_indices, str):
+        if parameter_indices == 'all':
+            parameter_indices = range(0, results[0].problem.dim_full)
+        elif parameter_indices == 'free_only':
+            parameter_indices = results[0].problem.x_free_indices
+        else:
+            raise ValueError("Permissible values for parameter_indices are "
+                             "'all', 'free_only' or a list of indices")
+
     for j, result in enumerate(results):
         # handle results and bounds
         (lb, ub, x_labels, fvals, xs) = \
             handle_inputs(result=result, lb=lb, ub=ub,
-                          free_indices_only=free_indices_only,
+                          parameter_indices=parameter_indices,
                           start_indices=start_indices)
 
         # call lowlevel routine
@@ -73,8 +97,10 @@ def parameters(results, ax=None, free_indices_only=True, lb=None, ub=None,
     # plot reference points
     for i_ref in ref:
         # reduce parameter vector in reference point, if necessary
-        if free_indices_only:
-            x_ref = np.array(result.problem.get_reduced_vector(i_ref['x']))
+        if len(parameter_indices) < results[0].problem.dim_full:
+            x_ref = np.array(results[0].problem.get_reduced_vector(
+                i_ref['x'],
+                parameter_indices))
         else:
             x_ref = np.array(i_ref['x'])
         x_ref = np.reshape(x_ref, (1, x_ref.size))
@@ -89,9 +115,19 @@ def parameters(results, ax=None, free_indices_only=True, lb=None, ub=None,
     return ax
 
 
-def parameters_lowlevel(xs, fvals, lb=None, ub=None, x_labels=None,
-                        ax=None, size=None, colors=None, linestyle='-',
-                        legend_text=None, balance_alpha=True):
+def parameters_lowlevel(
+        xs: Sequence[Union[np.ndarray, List[float]]],
+        fvals: Union[np.ndarray, List[float]],
+        lb: Optional[Union[np.ndarray, List[float]]] = None,
+        ub: Optional[Union[np.ndarray, List[float]]] = None,
+        x_labels: Optional[Iterable[str]] = None,
+        ax: Optional[matplotlib.axes.Axes] = None,
+        size: Optional[Tuple[float, float]] = None,
+        colors: Optional[Sequence[Union[np.ndarray, List[float]]]] = None,
+        linestyle: str = '-',
+        legend_text: Optional[str] = None,
+        balance_alpha: bool = True
+) -> matplotlib.axes.Axes:
 
     """
     Plot parameters plot using list of parameters.
@@ -99,42 +135,42 @@ def parameters_lowlevel(xs, fvals, lb=None, ub=None, x_labels=None,
     Parameters
     ----------
 
-    xs: nested list or array
+    xs:
         Including optimized parameters for each startpoint.
         Shape: (n_starts, dim).
 
-    fvals: numeric list or array
+    fvals:
         Function values. Needed to assign cluster colors.
 
-    lb, ub: array_like, optional
+    lb, ub:
         The lower and upper bounds.
 
-    x_labels: array_like of str, optional
+    x_labels:
         Labels to be used for the parameters.
 
-    ax: matplotlib.Axes, optional
+    ax:
         Axes object to use.
 
-    size: tuple, optional
+    size:
         see parameters
 
-    colors: list of RGBA
+    colors:
         One for each element in 'fvals'.
 
-    linestyle: str, optional
+    linestyle:
         linestyle argument for parameter plot
 
-    legend_text: str
+    legend_text:
         Label for line plots
 
-    balance_alpha: bool (optional)
+    balance_alpha:
         Flag indicating whether alpha for large clusters should be reduced to
         avoid overplotting (default: True)
 
     Returns
     -------
 
-    ax: matplotlib.Axes
+    ax:
         The plot axes.
     """
 
@@ -191,43 +227,46 @@ def parameters_lowlevel(xs, fvals, lb=None, ub=None, x_labels=None,
     return ax
 
 
-def handle_inputs(result, free_indices_only, lb=None, ub=None,
-                  start_indices=None):
+def handle_inputs(
+        result: Result, parameter_indices: List[int],
+        lb: Optional[Union[np.ndarray, List[float]]] = None,
+        ub: Optional[Union[np.ndarray, List[float]]] = None,
+        start_indices: Optional[Union[int, Iterable[int]]] = None
+) -> Tuple[np.ndarray, np.ndarray, List[str], np.ndarray, List[np.ndarray]]:
     """
     Computes the correct bounds for the parameter indices to be plotted and
-    outputs the corrsponding parameters and their labels
+    outputs the corresponding parameters and their labels
 
     Parameters
     ----------
 
-    result: pypesto.Result
+    result:
         Optimization result obtained by 'optimize.py'.
 
-    free_indices_only: bool, optional
-        If True, only free parameters are shown. If
-        False, also the fixed parameters are shown.
+    parameter_indices:
+        Specifies which parameters should be plotted.
 
-    lb, ub: ndarray, optional
+    lb, ub:
         If not None, override result.problem.lb, problem.problem.ub.
         Dimension either result.problem.dim or result.problem.dim_full.
 
-    start_indices: list or int
+    start_indices:
         list of integers specifying the multistarts to be plotted or
         int specifying up to which start index should be plotted
 
     Returns
     -------
 
-    lb, ub: ndarray
+    lb, ub:
         Dimension either result.problem.dim or result.problem.dim_full.
 
-    x_labels: list of str
+    x_labels:
         ytick labels to be applied later on
 
-    fvals: ndarray
+    fvals:
         objective function values which are needed for plotting later
 
-    xs: ndarray
+    xs:
         parameter values which will be plotted later
     """
 
@@ -261,12 +300,13 @@ def handle_inputs(result, free_indices_only, lb=None, ub=None,
     x_labels = result.problem.x_names
 
     # handle fixed and free indices
-    if free_indices_only:
+    if len(parameter_indices) < result.problem.dim_full:
         for ix, x in enumerate(xs_out):
-            xs_out[ix] = result.problem.get_reduced_vector(x)
-        lb = result.problem.get_reduced_vector(lb)
-        ub = result.problem.get_reduced_vector(ub)
-        x_labels = [x_labels[int(i)] for i in result.problem.x_free_indices]
+            xs_out[ix] = result.problem.get_reduced_vector(x,
+                                                           parameter_indices)
+        lb = result.problem.get_reduced_vector(lb, parameter_indices)
+        ub = result.problem.get_reduced_vector(ub, parameter_indices)
+        x_labels = [x_labels[int(i)] for i in parameter_indices]
     else:
         lb = result.problem.get_full_vector(lb)
         ub = result.problem.get_full_vector(ub)
